@@ -1,6 +1,6 @@
 /* -*- c-file-style: "GNU" -*- */
 /*
- * Copyright  CNRS, INRIA, Universit Bordeaux 1
+ * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
  * See COPYING in top-level directory.
  */
 
@@ -13,25 +13,15 @@
 #define NB_TRACES (*get_nb_traces())
 #define NB_START (*get_nb_start())
 #define CUR_TRACE (get_cur_trace())
-#define CUR_EV (get_cur_ev())
 #define SKIP (*get_skip())
 
-
 #define STARTED (CUR_TRACE->start != 0)
 
-#if TID_RECORDING_ENABLED
-#define CUR_THREAD_ID CUR_TRACE->ev.user.tid
+#define CUR_EV (get_cur_ev())
+#define CUR_THREAD_ID LITL_READ_GET_TID(&CUR_TRACE->ev)
+#define CURRENT (double)(((LITL_READ_GET_TIME(&CUR_TRACE->ev) - CUR_TRACE->start_time)+CUR_TRACE->delay)/1000000.0)
+#define CUR_TIME(i) (uint64_t)((LITL_READ_GET_TIME(&get_traces(i)->ev) - get_traces(i)->start_time) + get_traces(i)->delay)
 
-#define GET_PARAM(p_ev, num_param) (p_ev)->param[(num_param)-1]
-#define GET_NBPARAMS(p_ev) (p_ev)->nb_params
-#else
-#define CUR_THREAD_ID CUR_TRACE->ev.param[0]
-#define GET_PARAM(p_ev, num_param) (p_ev)->param[(num_param)]
-#define GET_NBPARAMS(p_ev) (p_ev)->nb_params-1
-#endif
-
-#define CURRENT (double)(((CUR_TRACE->ev.time - CUR_TRACE->start_time)+CUR_TRACE->delay)/1000000.0)
-#define CUR_TIME(i) (uint64_t)((get_traces(i)->ev.time - get_traces(i)->start_time) + get_traces(i)->delay)
 #define CUR_RANK (CUR_TRACE->rank)
 #define CUR_ID (CUR_TRACE->trace_id)
 #define CUR_INDEX (CUR_TRACE->id)
@@ -49,23 +39,22 @@
 #define CREATE_THREAD_ID_STR(__var__, __trace_id__, __tid__)	\
   asprintf (&(__var__), "%s_T#%u", __trace_id__, __tid__)
 
-
 /* create the process name string */
 #define CREATE_PROCESS_NAME_STR(__var__, __trace_index__)	\
   asprintf (&(__var__), "CT_Process #%d", __trace_index__)
 
 /* create the thread name string */
 #define CREATE_THREAD_NAME_STR(__var__, __trace_id__, __tid__)	\
-  asprintf (&(__var__), "%s_T#%llu", __trace_id__, __tid__)
+  asprintf (&(__var__), "%s_T#%llu", __trace_id__, (long long unsigned int) __tid__)
 
-
-static inline struct eztrace_container_t * get_thread_cont_from_id(int trace_id, int thread_id);
+static inline struct eztrace_container_t * get_thread_cont_from_id(
+    int trace_id, int thread_id);
 
 /* get a pointer to container */
 static inline struct eztrace_container_t*
 GET_ROOT_CONTAINER(int trace_index) {
   struct trace_t* ret = get_traces(trace_index);
-  if(ret)
+  if (ret)
     return &ret->root_container;
   return NULL;
 }
@@ -74,19 +63,18 @@ GET_ROOT_CONTAINER(int trace_index) {
 #define GET_THREAD_CONTAINER(__trace_index__, __thread_id__) get_thread_cont_from_id(__trace_index__, __thread_id__)
 
 /* get a pointer to the info structure */
-static inline
-struct process_info_t* GET_PROCESS_INFO(int trace_index) {
+static inline struct process_info_t* GET_PROCESS_INFO(int trace_index) {
   struct eztrace_container_t* ret = GET_PROCESS_CONTAINER(trace_index);
-  if(ret)
-    return (struct process_info_t*)(ret->container_info);
+  if (ret)
+    return (struct process_info_t*) (ret->container_info);
   return NULL;
 }
 
-static inline
-struct thread_info_t* GET_THREAD_INFO(int trace_index, int thread_id) {
+static inline struct thread_info_t* GET_THREAD_INFO(int trace_index,
+                                                    int thread_id) {
   struct eztrace_container_t* ret = GET_THREAD_CONTAINER(trace_index, thread_id);
-  if(ret)
-    return (struct thread_info_t*)(ret->container_info);
+  if (ret)
+    return (struct thread_info_t*) (ret->container_info);
   return NULL;
 }
 
@@ -94,35 +82,39 @@ struct thread_info_t* GET_THREAD_INFO(int trace_index, int thread_id) {
 static inline char*
 GET_PROCESS_ID_STR(int trace_index) {
   struct eztrace_container_t* ret = GET_ROOT_CONTAINER(trace_index);
-  if(ret)
+  if (ret)
     return ret->id;
   return NULL;
-};
+}
+;
 
 static inline char*
 GET_THREAD_ID_STR(int trace_index, int thread_id) {
   struct eztrace_container_t* ret = GET_THREAD_CONTAINER(trace_index, thread_id);
-  if(ret)
+  if (ret)
     return ret->id;
   return NULL;
-};
+}
+;
 
 /* get a pointer to the name string */
 static inline char*
 GET_PROCESS_NAME_STR(int trace_index) {
   struct eztrace_container_t* ret = GET_ROOT_CONTAINER(trace_index);
-  if(ret)
+  if (ret)
     return ret->name;
   return NULL;
-};
+}
+;
 
 static inline char*
 GET_THREAD_NAME_STR(int trace_index, int thread_id) {
   struct eztrace_container_t* ret = GET_THREAD_CONTAINER(trace_index, thread_id);
-  if(ret)
+  if (ret)
     return ret->name;
   return NULL;
-};
+}
+;
 
 /* Same as above, but the variable is declared. */
 #define DECLARE_PROCESS_INFO(__var__, __trace_index__)			\
@@ -137,7 +129,8 @@ GET_THREAD_NAME_STR(int trace_index, int thread_id) {
   char* __var__ = GET_PROCESS_NAME_STR(__trace_index__)
 
 #define DECLARE_THREAD_ID_STR(__var__, __trace_index__, __thread_id__)	\
-  char* __var__ = GET_THREAD_ID_STR(__trace_index__, __thread_id__)
+  char *__var__ __attribute__ ((__unused__)); \
+  __var__ = GET_THREAD_ID_STR(__trace_index__, __thread_id__)
 #define DECLARE_THREAD_NAME_STR(__var__, __trace_index__, __thread_id__) \
   char* __var__ = GET_THREAD_NAME_STR(__trace_index__, __thread_id__)
 
@@ -161,8 +154,6 @@ GET_THREAD_NAME_STR(int trace_index, int thread_id) {
  */
 #define CHANGE() if(CUR_TRACE->start)
 
-
-
 /* create an identifier for a specific application pointer
  * This identifier is only valid within the current process.
  */
