@@ -1,3 +1,6 @@
+# Copyright (C) CNRS, INRIA, Université Bordeaux 1, Télécom SudParis
+# See COPYING in top-level directory.
+
 package Function;
 use warnings;
 use strict;
@@ -20,7 +23,7 @@ sub new {
     $this->{ENTRY_CODE}= 0;
     $this->{EXIT_CODE}= 0;
 
-    $this->{BODY_BEGIN}="";
+    $this->{BODY_BEGIN}="  FUNCTION_ENTRY\n";
     $this->{BODY_FCALL}="";
     $this->{BODY_END}="";
     $this->{USE_VARGS}=0;
@@ -49,12 +52,24 @@ sub convert_declare_parameters {
     if ($this->{TYPE} eq "LIBRARY") {
 
 	my $i;
+	my $get_param_str="GET_PARAM_PACKED_".$nb_param."(CUR_EV, ";
+
 	for($i=0; $i<$nb_param; $i++) {
 	    # declare a variable
-	    $string .= get_arg_type($this, $i). " ".get_arg_name($this, $i);
+	    $string .= get_arg_type($this, $i). " ".get_arg_name($this, $i). ";\n" ;
 	    # put the i_th parameter of the event in the variable
-	    $string .= " = (".get_arg_type($this, $i).") GET_PARAM(CUR_EV, ".($i+1).");\n";
+
+	    $get_param_str.= get_arg_name($this, $i);
+	    if($i+1 < $nb_param) {
+            #there is another parameter after this one
+		$get_param_str .= ", ";
+	    }
 	}
+	$get_param_str .= ");\n";
+	if($nb_param > 0) {
+	    $string .= $get_param_str;
+	}
+
     }
     return $string;
 }
@@ -74,7 +89,7 @@ sub add_event {
     }
     my $string = "";
     if ($this->{TYPE} eq "LIBRARY") {
-	$string .= "EZTRACE_EVENT${nb_param} ($code";
+	$string .= "EZTRACE_EVENT_PACKED_${nb_param} ($code";
 	my $i;
 	for($i=0; $i<$nb_param; $i++) {
 	    $string .= ", ";
