@@ -1,6 +1,6 @@
 /* -*- c-file-style: "GNU" -*- */
 /*
- * Copyright  CNRS, INRIA, Universit Bordeaux 1
+ * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
  * See COPYING in top-level directory.
  */
 
@@ -15,10 +15,11 @@
 
 #include "memory_ev_codes.h"
 #include "eztrace.h"
+#include "eztrace_litl_packed.h"
 #include "pptrace.h"
 
 /* set to 1 when all the hooks are set.
- * This is usefull in order to avoid recursive calls
+ * This is useful in order to avoid recursive calls
  */
 static int __memory_initialized = 0;
 
@@ -31,8 +32,7 @@ static int __memory_initialized = 0;
  * (if not aligned, some weird bugs may happen when using -O3)
  */
 enum __memory_type {
-  MEM_TYPE_MALLOC,
-  MEM_TYPE_CUSTOM_MALLOC
+  MEM_TYPE_MALLOC, MEM_TYPE_CUSTOM_MALLOC
 };
 
 /* todo: we could add information like:
@@ -41,16 +41,16 @@ enum __memory_type {
  * - NUMA node ?
  */
 struct mem_block_info {
-  void* u_ptr;		/* address of the user block */
-  void* p_ptr;		/* address of the padding */
+  void* u_ptr; /* address of the user block */
+  void* p_ptr; /* address of the padding */
 
   enum __memory_type mem_type;
 
-  size_t total_size; 		/* size allocated (including this structure) */
-  size_t size;			/* size of the buffer (not including this structure) */
+  size_t total_size; /* size allocated (including this structure) */
+  size_t size; /* size of the buffer (not including this structure) */
 
   /* WARNING: this must be the last field of the structure */
-  uint32_t canary;		/* this is used for checking that we malloc'ed the buffer */
+  uint32_t canary; /* this is used for checking that we malloc'ed the buffer */
 }__attribute__((__packed__));
 
 /* size of the padding + mem_info structure */
@@ -81,7 +81,6 @@ struct mem_block_info {
     (p_ptr) = b_ptr->p_ptr;			\
   } while(0)
 
-
 /* fill a mem_info structure
  * @param p_mem the mem_info* structure to fill
  * @param ptr the address returned by (m,c,re)alloc
@@ -102,33 +101,31 @@ struct mem_block_info {
     p_mem->canary = MAGIC_PATTERN;				\
   } while(0)
 
-
-
 /* todo: also implement mmap and munmap ?
  */
 void* (*libcalloc)(size_t nmemb, size_t size);
 void* (*libmalloc)(size_t size) = NULL;
-void  (*libfree)(void *ptr);
+void (*libfree)(void *ptr);
 void* (*librealloc)(void *ptr, size_t size);
 
 static int malloc_protect_on = 0;
 
-/* Custom malloc function. It is used when libmalloc=NULL (ie. during startup)
- * This function is not thread-safe and is very likely to be bogus, so use with caution
+/* Custom malloc function. It is used when libmalloc=NULL (e.g. during startup)
+ * This function is not thread-safe and is very likely to be bogus, so use with
+ * caution
  */
-static void* hand_made_malloc(size_t size)
-{
+static void* hand_made_malloc(size_t size) {
   /* allocate a 1MB buffer */
-#define POOL_SIZE (1024*1024)
-  static char mem[POOL_SIZE] = { '\0' };
+#define POOL_SIZE (1024 * 1024)
+  static char mem[POOL_SIZE] = {'\0'};
 
-  /* since this function is only used before we found libmalloc, there's no fancy
-   * memory management mechanism (block reuse, etc.)
+  /* since this function is only used before we found libmalloc, there's no
+   * fancy memory management mechanism (block reuse, etc.)
    */
   static char* next_slot = &mem[0];
   static int total_alloc = 0;
 
-  if(libmalloc)
+  if (libmalloc)
     /* let's use the real malloc */
     return malloc(size);
 
@@ -142,20 +139,22 @@ static void* hand_made_malloc(size_t size)
   return p_block->u_ptr;
 }
 
-void* malloc(size_t size)
-{
-  /* if memory_init hasn't been called yet, we need to get libc's malloc address */
+void* malloc(size_t size) {
+  /* if memory_init hasn't been called yet, we need to get libc's malloc
+   * address
+   */
 
   if (!libmalloc) {
-    if(malloc_protect_on)
-      /* protection flag says that malloc is already trying to retrieve the address of malloc.
-       * if we call dlsym now, there will be an infinite recursion, so let's allocate
-       * memory 'by hand'
+    if (malloc_protect_on)
+      /* protection flag says that malloc is already trying to retrieve the
+       * address of malloc.
+       * If we call dlsym now, there will be an infinite recursion, so let's
+       * allocate memory 'by hand'
        */
       return hand_made_malloc(size);
 
     /* set the protection flag and retrieve the address of malloc.
-     * if dlsym calls malloc, memory will be allocated 'by hand'
+     * If dlsym calls malloc, memory will be allocated 'by hand'
      */
     malloc_protect_on = 1;
     libmalloc = dlsym(RTLD_NEXT, "malloc");
@@ -174,7 +173,7 @@ void* malloc(size_t size)
     INIT_MEM_INFO(p_block, pptr, size, 1);
     p_block->mem_type = MEM_TYPE_MALLOC;
 
-    EZTRACE_EVENT2(FUT_MEMORY_MALLOC, p_block->size, p_block->u_ptr);
+    EZTRACE_EVENT_PACKED_2(EZTRACE_MEMORY_MALLOC, p_block->size, (app_ptr)p_block->u_ptr);
 
 #if 0
     /* for debugging purpose only */
@@ -189,15 +188,14 @@ void* malloc(size_t size)
   return libmalloc(size);
 }
 
-void* realloc(void *ptr, size_t size)
-{
+void* realloc(void *ptr, size_t size) {
 
   /* if ptr is NULL, realloc behaves like malloc */
-  if(!ptr)
+  if (!ptr)
     return malloc(size);
 
   /* if size=0 and ptr isn't NULL, realloc behaves like free */
-  if(!size && ptr) {
+  if (!size && ptr) {
     free(ptr);
     return NULL;
   }
@@ -211,7 +209,7 @@ void* realloc(void *ptr, size_t size)
     }
   }
 
-  if(!CANARY_OK(ptr)) {
+  if (!CANARY_OK(ptr)) {
     /* we didn't malloc'ed this buffer */
     return librealloc(ptr, size);
   }
@@ -222,33 +220,35 @@ void* realloc(void *ptr, size_t size)
     size_t old_size = p_block->size;
     size_t header_size = p_block->total_size - p_block->size;
 
-    if(p_block->mem_type != MEM_TYPE_MALLOC) {
-      fprintf(stderr, "Warning: realloc a ptr that was allocated by hand_made_malloc\n");
+    if (p_block->mem_type != MEM_TYPE_MALLOC) {
+      fprintf(
+          stderr,
+          "Warning: realloc a ptr that was allocated by hand_made_malloc\n");
     }
 
     void *pptr = librealloc(p_block->p_ptr, size + header_size);
 
-    if(!p_block) {
+    if (!p_block) {
       return NULL;
     }
 
-    INIT_MEM_INFO(p_block, pptr, size+header_size, 1);
+    INIT_MEM_INFO(p_block, pptr, size + header_size, 1);
 
     p_block->mem_type = MEM_TYPE_MALLOC;
 
-    EZTRACE_EVENT3(FUT_MEMORY_REALLOC, old_size, p_block->size, p_block->u_ptr);
+    EZTRACE_EVENT_PACKED_3(EZTRACE_MEMORY_REALLOC, old_size, p_block->size, (app_ptr)p_block->u_ptr);
+
     return p_block->u_ptr;
   }
 
   return librealloc(ptr, size);
 }
 
-void* calloc(size_t nmemb, size_t size)
-{
+void* calloc(size_t nmemb, size_t size) {
   if (!libcalloc) {
-    void* ret = malloc(nmemb*size);
-    if(ret) {
-      memset(ret, 0, nmemb*size);
+    void* ret = malloc(nmemb * size);
+    if (ret) {
+      memset(ret, 0, nmemb * size);
     }
     return ret;
   }
@@ -256,7 +256,7 @@ void* calloc(size_t nmemb, size_t size)
   EZTRACE_PROTECT {
     /* compute the number of blocks for header */
     int nb_memb_header = sizeof(struct mem_block_info) / size;
-    if(size*nb_memb_header < sizeof(struct mem_block_info))
+    if (size * nb_memb_header < sizeof(struct mem_block_info))
       nb_memb_header++;
 
     /* allocate buffer + header */
@@ -266,7 +266,7 @@ void* calloc(size_t nmemb, size_t size)
     INIT_MEM_INFO(p_block, p_ptr, nmemb, size);
     p_block->mem_type = MEM_TYPE_MALLOC;
 
-    EZTRACE_EVENT2(FUT_MEMORY_MALLOC, p_block->size, p_block->u_ptr);
+    EZTRACE_EVENT_PACKED_2(EZTRACE_MEMORY_MALLOC, p_block->size, (app_ptr)p_block->u_ptr);
 
 #if 0
     /* for debugging purpose only */
@@ -281,8 +281,7 @@ void* calloc(size_t nmemb, size_t size)
   return libcalloc(nmemb, size);
 }
 
-void free(void* ptr)
-{
+void free(void* ptr) {
   if (!libfree) {
     libfree = dlsym(RTLD_NEXT, "free");
     char* error;
@@ -292,16 +291,16 @@ void free(void* ptr)
     }
   }
 
-  if(!ptr) {
-      libfree(ptr);
-      return ;
+  if (!ptr) {
+    libfree(ptr);
+    return;
   }
 
   /* first, check wether we malloc'ed the buffer */
-  if(!CANARY_OK(ptr)){
+  if (!CANARY_OK(ptr)) {
     /* we didn't malloc this buffer */
     libfree(ptr);
-    return ;
+    return;
   }
 
   /* retrieve the block information and free it */
@@ -309,8 +308,8 @@ void free(void* ptr)
     struct mem_block_info *p_block;
     USER_PTR_TO_BLOCK_INFO(ptr, p_block);
 
-    if(p_block->mem_type == MEM_TYPE_MALLOC) {
-      EZTRACE_EVENT2(FUT_MEMORY_FREE, p_block->size, p_block->u_ptr);
+    if (p_block->mem_type == MEM_TYPE_MALLOC) {
+      EZTRACE_EVENT_PACKED_2(EZTRACE_MEMORY_FREE, p_block->size, (app_ptr)p_block->u_ptr);
       libfree(p_block->p_ptr);
     } else {
       /* the buffer was allocated by hand_made_malloc, there's nothing to free */
@@ -318,29 +317,24 @@ void free(void* ptr)
   }
 }
 
-START_INTERCEPT
-  INTERCEPT2("malloc", libmalloc)
-  INTERCEPT2("calloc", libcalloc)
-  INTERCEPT2("realloc", librealloc)
-  INTERCEPT2("free", libfree)
+START_INTERCEPT INTERCEPT2("malloc", libmalloc)
+INTERCEPT2("calloc", libcalloc)
+INTERCEPT2("realloc", librealloc)
+INTERCEPT2("free", libfree)
 END_INTERCEPT
 
-static void __memory_init (void) __attribute__ ((constructor));
-static void
-__memory_init (void)
-{
+static void __memory_init(void) __attribute__ ((constructor));
+static void __memory_init(void) {
 
- DYNAMIC_INTERCEPT_ALL();
+  DYNAMIC_INTERCEPT_ALL();
 #ifdef EZTRACE_AUTOSTART
   eztrace_start ();
 #endif
   __memory_initialized = 1;
 }
 
-static void __memory_conclude (void) __attribute__ ((destructor));
-static void
-__memory_conclude (void)
-{
+static void __memory_conclude(void) __attribute__ ((destructor));
+static void __memory_conclude(void) {
   __memory_initialized = 0;
-  eztrace_stop ();
+  eztrace_stop();
 }
