@@ -1,6 +1,6 @@
 /* -*- c-file-style: "GNU" -*- */
 /*
- * Copyright © CNRS, INRIA, Université Bordeaux 1
+ * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
  * See COPYING in top-level directory.
  */
 
@@ -21,7 +21,6 @@
 #include "mpi_ev_codes.h"
 #include "eztrace.h"
 
-
 static void MPI_Allreduce_prolog (CONST void *sendbuf __attribute__((unused)),
 				  void *recvbuf __attribute__((unused)),
 				  int count __attribute__((unused)),
@@ -37,13 +36,13 @@ static void MPI_Allreduce_prolog (CONST void *sendbuf __attribute__((unused)),
   int len;
   MPI_Type_size(datatype, &len);
 
-  EZTRACE_EVENT3(FUT_MPI_START_Allreduce, comm, size, rank);
+  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_START_Allreduce, (app_ptr)comm, size, rank);
 }
 
-static int MPI_Allreduce_core (CONST void *sendbuf, void *recvbuf, int count,
-			       MPI_Datatype datatype, MPI_Op op, MPI_Comm comm)
+static int MPI_Allreduce_core(CONST void *sendbuf, void *recvbuf, int count,
+                              MPI_Datatype datatype, MPI_Op op, MPI_Comm comm)
 {
-  return libMPI_Allreduce (sendbuf, recvbuf, count, datatype, op, comm);
+  return libMPI_Allreduce(sendbuf, recvbuf, count, datatype, op, comm);
 }
 
 static void MPI_Allreduce_epilog (CONST void *sendbuf __attribute__((unused)),
@@ -61,31 +60,31 @@ static void MPI_Allreduce_epilog (CONST void *sendbuf __attribute__((unused)),
   int len;
   MPI_Type_size(datatype, &len);
 
-  EZTRACE_EVENT3(FUT_MPI_STOP_Allreduce, comm, size, rank);
+  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_STOP_Allreduce, (app_ptr)comm, size, rank);
 }
 
-
 int MPI_Allreduce (CONST void *sendbuf, void *recvbuf, int count,
                    MPI_Datatype datatype, MPI_Op op, MPI_Comm comm)
 {
   FUNCTION_ENTRY;
 
-  MPI_Allreduce_prolog (sendbuf, recvbuf, count, datatype, op, comm);
-  int ret = MPI_Allreduce_core (sendbuf, recvbuf, count, datatype, op, comm);
-  MPI_Allreduce_epilog (sendbuf, recvbuf, count, datatype, op, comm);
+  MPI_Allreduce_prolog(sendbuf, recvbuf, count, datatype, op, comm);
+  int ret = MPI_Allreduce_core(sendbuf, recvbuf, count, datatype, op, comm);
+  MPI_Allreduce_epilog(sendbuf, recvbuf, count, datatype, op, comm);
   return ret;
 }
 
-
-void mpif_allreduce_(void *sbuf, void *rbuf, int *count,
-		     MPI_Fint *d, MPI_Fint *op,
-		     MPI_Fint *c, int *error)
-{
+void mpif_allreduce_(void *sbuf, void *rbuf, int *count, MPI_Fint *d,
+                     MPI_Fint *op, MPI_Fint *c, int *error) {
+  FUNCTION_ENTRY;
   MPI_Datatype c_type = MPI_Type_f2c(*d);
   MPI_Op c_op = MPI_Op_f2c(*op);
   MPI_Comm c_comm = MPI_Comm_f2c(*c);
+  void *c_sbuf = CHECK_MPI_IN_PLACE(sbuf);
+  void *c_rbuf = CHECK_MPI_IN_PLACE(rbuf);
 
-  MPI_Allreduce_prolog(sbuf, rbuf, *count, c_type, c_op, c_comm);
-  *error = MPI_Allreduce_core(sbuf, rbuf, *count, c_type, c_op, c_comm);
-  MPI_Allreduce_epilog(sbuf, rbuf, *count, c_type, c_op, c_comm);
+  MPI_Allreduce_prolog(c_sbuf, c_rbuf, *count, c_type, c_op, c_comm);
+  *error = MPI_Allreduce_core(c_sbuf, c_rbuf, *count, c_type, c_op, c_comm);
+
+  MPI_Allreduce_epilog(c_sbuf, c_rbuf, *count, c_type, c_op, c_comm);
 }
