@@ -1,6 +1,6 @@
 /* -*- c-file-style: "GNU" -*- */
 /*
- * Copyright © CNRS, INRIA, Université Bordeaux 1
+ * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
  * See COPYING in top-level directory.
  */
 
@@ -21,9 +21,8 @@
 #include "mpi_ev_codes.h"
 #include "eztrace.h"
 
-
-static int MPI_Irsend_core (CONST void* buf, int count, MPI_Datatype datatype, int dest, int tag,
-			    MPI_Comm comm, MPI_Request *req)
+static int MPI_Irsend_core(CONST void* buf, int count, MPI_Datatype datatype,
+                           int dest, int tag, MPI_Comm comm, MPI_Request *req)
 {
   return libMPI_Irsend(buf, count, datatype, dest, tag, comm, req);
 }
@@ -38,26 +37,25 @@ static void MPI_Irsend_epilog (CONST void* buf __attribute__((unused)),
 {
   int size;
   MPI_Type_size(datatype, &size);
-  EZTRACE_EVENT5 (FUT_MPI_IRSEND, count*size, dest, tag, req, comm);
+   EZTRACE_EVENT_PACKED_5(EZTRACE_MPI_IRSEND, count*size, dest, tag, (app_ptr)req, (app_ptr)comm);
 }
 
-
-int MPI_Irsend (CONST void* buf, int count, MPI_Datatype datatype, int dest, int tag, MPI_Comm comm, MPI_Request *req)
+int MPI_Irsend(CONST void* buf, int count, MPI_Datatype datatype, int dest,
+               int tag, MPI_Comm comm, MPI_Request *req)
 {
   FUNCTION_ENTRY;
   int ret = MPI_Irsend_core(buf, count, datatype, dest, tag, comm, req);
-  MPI_Irsend_epilog(buf, count, datatype, dest, tag, comm, (MPI_Fint*)req);
+  MPI_Irsend_epilog(buf, count, datatype, dest, tag, comm, (MPI_Fint*) req);
   return ret;
 }
 
-
-void mpif_irsend_(void *buf, int *count, MPI_Fint *d, int *dest,
-		  int *tag, MPI_Fint *c, MPI_Fint *r, int *error)
-{
+void mpif_irsend_(void *buf, int *count, MPI_Fint *d, int *dest, int *tag,
+                  MPI_Fint *c, MPI_Fint *r, int *error) {
+  FUNCTION_ENTRY;
   MPI_Comm c_comm = MPI_Comm_f2c(*c);
   MPI_Datatype c_type = MPI_Type_f2c(*d);
   MPI_Request c_req = MPI_Request_f2c(*r);
   *error = MPI_Irsend_core(buf, *count, c_type, *dest, *tag, c_comm, &c_req);
-  *r= MPI_Request_c2f(c_req);
+  *r = MPI_Request_c2f(c_req);
   MPI_Irsend_epilog(buf, *count, c_type, *dest, *tag, c_comm, r);
 }
