@@ -1,6 +1,6 @@
 /* -*- c-file-style: "GNU" -*- */
 /*
- * Copyright © CNRS, INRIA, Université Bordeaux 1
+ * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
  * See COPYING in top-level directory.
  */
 
@@ -21,7 +21,6 @@
 #include "mpi_ev_codes.h"
 #include "eztrace.h"
 
-
 static void MPI_Scatterv_prolog(CONST void *sendbuf __attribute__((unused)),
 				CONST int *sendcnts __attribute__((unused)),
 				CONST int *displs __attribute__((unused)),
@@ -37,10 +36,7 @@ static void MPI_Scatterv_prolog(CONST void *sendbuf __attribute__((unused)),
   libMPI_Comm_size(comm, &size);
   libMPI_Comm_rank(comm, &rank);
 
-  int rsize;
-  MPI_Type_size(recvtype, &rsize);
-
-  EZTRACE_EVENT5(FUT_MPI_START_Scatterv, comm, size, rank, rsize*recvcnt, root);
+  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_START_Scatterv, (app_ptr)comm, size, rank);
 }
 
 static int MPI_Scatterv_core(CONST void *sendbuf,
@@ -53,7 +49,8 @@ static int MPI_Scatterv_core(CONST void *sendbuf,
 			     int root,
 			     MPI_Comm comm)
 {
-  return libMPI_Scatterv(sendbuf, sendcnts, displs, sendtype, recvbuf, recvcnt, recvtype, root, comm);
+  return libMPI_Scatterv(sendbuf, sendcnts, displs, sendtype, recvbuf, recvcnt,
+                         recvtype, root, comm);
 }
 
 static void MPI_Scatterv_epilog(CONST void *sendbuf __attribute__((unused)),
@@ -68,14 +65,14 @@ static void MPI_Scatterv_epilog(CONST void *sendbuf __attribute__((unused)),
 {
   int rank = -1;
   int size = -1;
+  int i = 0;
   libMPI_Comm_size(comm, &size);
   libMPI_Comm_rank(comm, &rank);
 
-  EZTRACE_EVENT3(FUT_MPI_STOP_Scatterv, comm, size, rank);
+  EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_STOP_Scatterv, (app_ptr)comm, size, rank);
 
 }
 
-
 int MPI_Scatterv(CONST void *sendbuf,
 		 CONST int *sendcnts,
 		 CONST int *displs,
@@ -87,30 +84,31 @@ int MPI_Scatterv(CONST void *sendbuf,
 		 MPI_Comm comm)
 {
   FUNCTION_ENTRY;
-  MPI_Scatterv_prolog(sendbuf, sendcnts, displs, sendtype, recvbuf, recvcnt, recvtype, root, comm);
-  int ret = MPI_Scatterv_core(sendbuf, sendcnts, displs, sendtype, recvbuf, recvcnt, recvtype, root, comm);
-  MPI_Scatterv_epilog(sendbuf, sendcnts, displs, sendtype, recvbuf, recvcnt, recvtype, root, comm);
+  MPI_Scatterv_prolog(sendbuf, sendcnts, displs, sendtype, recvbuf, recvcnt,
+                      recvtype, root, comm);
+  int ret = MPI_Scatterv_core(sendbuf, sendcnts, displs, sendtype, recvbuf,
+                              recvcnt, recvtype, root, comm);
+  MPI_Scatterv_epilog(sendbuf, sendcnts, displs, sendtype, recvbuf, recvcnt,
+                      recvtype, root, comm);
   return ret;
 }
 
-
 void mpif_scatterv_(void *sbuf, int *scount, int *displs, MPI_Fint *sd,
-		    void *rbuf, int *rcount, MPI_Fint *rd,
-		    int *root, MPI_Fint *c, int *error)
-{
+                    void *rbuf, int *rcount, MPI_Fint *rd, int *root,
+                    MPI_Fint *c, int *error) {
+  FUNCTION_ENTRY;
   MPI_Datatype c_stype = MPI_Type_f2c(*sd);
   MPI_Datatype c_rtype = MPI_Type_f2c(*rd);
   MPI_Comm c_comm = MPI_Comm_f2c(*c);
+  void *c_sbuf = CHECK_MPI_IN_PLACE(sbuf);
+  void *c_rbuf = CHECK_MPI_IN_PLACE(rbuf);
 
-  MPI_Scatterv_prolog(sbuf, scount, displs, c_stype,
-		      rbuf, *rcount, c_rtype,
-		      *root, c_comm);
+  MPI_Scatterv_prolog(sbuf, scount, displs, c_stype, c_rbuf, *rcount, c_rtype,
+                      *root, c_comm);
 
-  *error = MPI_Scatterv_core(sbuf, scount, displs, c_stype,
-			     rbuf, *rcount, c_rtype,
-			     *root, c_comm);
+  *error = MPI_Scatterv_core(sbuf, scount, displs, c_stype, c_rbuf, *rcount,
+                             c_rtype, *root, c_comm);
 
-  MPI_Scatterv_epilog(sbuf, scount, displs, c_stype,
-		      rbuf, *rcount, c_rtype,
-		      *root, c_comm);
+  MPI_Scatterv_epilog(sbuf, scount, displs, c_stype, c_rbuf, *rcount, c_rtype,
+                      *root, c_comm);
 }
