@@ -1,4 +1,9 @@
+/* -*- c-file-style: "GNU" -*- */
 /*
+ * Copyright (C) CNRS, INRIA, Université Bordeaux 1, Télécom SudParis
+ * See COPYING in top-level directory.
+ *
+ *
  * opcodes.c
  *
  * Wrapper to include the good set of opcodes. If we ever
@@ -12,8 +17,11 @@
 #include <config.h>
 #include <opcodes.h>
 
+#if __x86_64__
+// x86_64
+
 //#ifndef __PPTRACE_ARCH_TYPE
-#include "opcodes/intel.c"
+#include "cpu/intel.c"
 //#else
 
 //#if __PPTRACE_ARCH_TYPE == PPTRACE_ARCH_TYPE_XXX
@@ -24,3 +32,7 @@
 
 //#endif // !defined(__PTRACE_ARCH_TYPE)
 
+#elif __arm__
+// ARMv7 -- ARM cortex-A9
+#include "cpu/arm.c"
+#endif
