@@ -1,4 +1,9 @@
+/* -*- c-file-style: "GNU" -*- */
 /*
+ * Copyright (C) CNRS, INRIA, Université Bordeaux 1, Télécom SudParis
+ * See COPYING in top-level directory.
+ *
+ *
  * tracing.c
  *
  * Wrapper to include the good library for tracing processes
@@ -14,7 +19,7 @@
 #include <tracing.h>
 
 //#ifndef __PPTRACE_TRACE_TYPE
-#include "tracing/linux.c"
+#include "os/linux/linux.c"
 //#else
 
 //#if __PPTRACE_TRACE_TYPE == PPTRACE_TRACE_TYPE_BSD
